.. _Watchdog: https://github.com/gorakhargosh/watchdog
.. _click: http://click.pocoo.org/6/
.. _libsass: https://github.com/dahlia/libsass-python

========
Boussole
========

This is a commandline interface to build SASS projects using `libsass`_.

Alike the Compass commandline, there is 'build' and 'watch' actions to build all SASS files.

.. Warning::
    This is under construction, almost an Alpha for now.

.. Note::
    Old SASS syntax (the *indented syntax*) is not totally supported and actually this is not really planned to do it.

Links
*****

* Read the documentation on `Read the docs <http://boussole.readthedocs.org/>`_;
* Download its `PyPi package <http://pypi.python.org/pypi/boussole>`_;
* Clone it on its `Github repository <https://github.com/sveetch/boussole>`_;

Requires
********

* `Watchdog`_ == 0.8.3;
* `click`_ == 6.2;
* `libsass`_ == 0.10.1;
